"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var lintRunner_1 = require("./lintRunner");
var noAsyncWithoutAwaitRule_1 = require("./noAsyncWithoutAwaitRule");
var rule = 'no-async-without-await';
describe('noAsyncWithoutAwait Rule', function () {
    describe('Functions', function () {
        it("should fail when the async function doesn't have an await", function () {
            var src = "\n            async function a(){\n               let b = 1;\n               console.log(b);\n               \n            }\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(1);
        });
        it('should fail with correct message', function () {
            var src = "async function a(){\n               let b = 1;\n               console.log(b);\n               \n            }\n        ";
            var startPosition = src.indexOf('async');
            var endPosition = startPosition + 'async'.length;
            var failure = lintRunner_1.helper({ src: src, rule: rule }).failures[0];
            expect(failure.getStartPosition().getPosition()).toEqual(startPosition);
            expect(failure.getEndPosition().getPosition()).toEqual(endPosition);
            expect(failure.getFailure()).toBe(noAsyncWithoutAwaitRule_1.Rule.FAILURE_STRING);
        });
        it('should not fail when the async function has an await', function () {
            var src = "\n            async function a(){\n               let b = 1;\n               await console.log(b);\n               \n            }\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(0);
        });
        it('should not fail when the async function has an await inside a function call', function () {
            var src = "\n            async function a(){\n               let b = 1;\n               console.log(await b());\n               \n            }\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(0);
        });
        it('should fail when the async function has an await inside a arrow function declaration', function () {
            var src = "\n            async function a(){\n               let b = 1;\n               let b = async () => {\n                    await fetch();               \n               };\n               \n            }\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(1);
        });
        it('should fail when the async function has an await inside a regular function declaration', function () {
            var src = "\n            async function a(){\n               let b = 1;\n               async function f() {\n                    await fetch();               \n               };\n               \n            }\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(1);
        });
        it('should fail when the function is not at the top level', function () {
            var src = "\n            function a(){\n               let b = 1;\n               async function f() {\n                    fetch();               \n               };\n               \n            }\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(1);
        });
    });
    describe('Arrow functions', function () {
        it("should fail when the async arrow function doesn't have an await", function () {
            var src = "\n            const a = async () => {\n               let b = 1;\n               console.log(b);\n            }\n            ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(1);
        });
    });
    describe('Classes', function () {
        it('should fail when async class method has no await', function () {
            var src = "\n            class A {\n                async b() {\n                    console.log(1);\n                }\n            \n            }\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(1);
        });
        it('should not fail when async class method has await', function () {
            var src = "\n            class A {\n                async b() {\n                    await b();\n                }\n            \n            }\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(0);
        });
        it('should check classes that are inside functions', function () {
            var src = "\n          async () => {\n            await a();\n            class A {\n                async b() {\n                    console.log(1);\n                }\n            \n            }\n          };\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(1);
        });
    });
    describe('return statements', function () {
        it('should not fail when the async function has a return statement', function () {
            var src = "\n            async function a() {\n               let b = 1;\n               return b;\n            }\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(0);
        });
        it('should fail when the async function has a return statement', function () {
            var src = "\n            async function a() {\n               let b = 1;\n               let a = () => {\n                return 1;\n               }\n            }\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(1);
        });
        it('should not fail when the async function has a short return statement', function () {
            var src = "\n            let a = async () => 1;\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(0);
        });
    });
});
//# sourceMappingURL=noAsyncWithoutAwaitRule.spec.js.map