"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var lintRunner_1 = require("./lintRunner");
var rule = 'no-untyped-public-signature';
describe('noUntypedPublicSignatureRule', function () {
    describe('default options', function () {
        it('should not allow :any in public signature', function () {
            var src = "\n            class A {\n                public b(c:any):void {\n                \n                }\n            }\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(1);
            expect(result.failures[0].getFailure()).toBe('All arguments of public method must have types.');
        });
        it('should not allow untyped public signature', function () {
            var src = "\n            class A {\n                public b(c):void {\n                \n                }\n            }\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(1);
            expect(result.failures[0].getFailure()).toBe('All arguments of public method must have types.');
        });
        it('should fail on implicit public methods', function () {
            var src = "\n                class A {\n                  a(c) {\n                  }\n                }";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(2);
        });
        it('should fail on async implicit public methods', function () {
            var src = "\n                class A {\n                  async a(c) {\n                  }\n                }";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(2);
        });
        it('should not fail on private untyped method', function () {
            var src = "\n                class A {\n                  private a(c) {\n                  }\n                }";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(0);
        });
        it('should not fail on private async untyped method', function () {
            var src = "\n                class A {\n                  async private a(c) {\n                  }\n                }";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(0);
        });
        it('should not allow untyped return value', function () {
            var src = "\n            class A {\n                public b() {\n                \n                }\n            }\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(1);
            expect(result.failures[0].getFailure()).toBe('Public methods must have return type.');
        });
        it('should raise two errors when method has untyped parameter and untyped return value', function () {
            var src = "\n            class A {\n                public b(c) {\n                \n                }\n            }\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(2);
            expect(result.failures[0].getFailure()).toBe('All arguments of public method must have types.');
            expect(result.failures[1].getFailure()).toBe('Public methods must have return type.');
        });
        it('should not allow :any return value', function () {
            var src = "\n            class A {\n                public b(): any {\n                \n                }\n            }\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(1);
            expect(result.failures[0].getFailure()).toBe('Public methods must have return type.');
        });
        it('should allow typed public signature', function () {
            var src = "\n            class A {\n                public b(c: string):void {\n                \n                }\n            }\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(0);
        });
        it('should allow untyped argument when using spread operator', function () {
            var src = "\n            class A {\n                public b(...c):void {\n                \n                }\n            }\n        ";
            var result = lintRunner_1.helper({ src: src, rule: rule });
            expect(result.errorCount).toBe(0);
        });
    });
    describe('with "any-allowed" argument', function () {
        it('should allow :any return type', function () {
            var src = "\n            class A {\n                public b():any {\n                \n                }\n            }\n            ";
            var result = lintRunner_1.helper({
                src: src,
                rule: { name: rule, options: 'allow-any' },
            });
            expect(result.errorCount).toBe(0);
        });
        it('should allow :any argument type', function () {
            var src = "\n            class A {\n                public b(c:any):any {\n                \n                }\n            }\n            ";
            var result = lintRunner_1.helper({
                src: src,
                rule: { name: rule, options: 'allow-any' },
            });
            expect(result.errorCount).toBe(0);
        });
    });
    describe('with allowed methods', function () {
        it('should allow untyped public method', function () {
            var src = "\n            class A {\n                public componentWillMount() {\n                }\n                \n                render() {\n                }\n            }\n            ";
            var result = lintRunner_1.helper({
                src: src,
                rule: {
                    name: rule,
                    options: [{ allowedMethods: ['componentWillMount', 'render'] }],
                },
            });
            expect(result.errorCount).toBe(0);
        });
        it('should support multiple allowedMethods options', function () {
            var src = "\n            class A {\n                public componentWillMount() {\n                }\n                \n                render() {\n                }\n            }\n            ";
            var result = lintRunner_1.helper({
                src: src,
                rule: {
                    name: rule,
                    options: [
                        { allowedMethods: ['componentWillMount'] },
                        { allowedMethods: ['render'] },
                    ],
                },
            });
            expect(result.errorCount).toBe(0);
        });
    });
});
//# sourceMappingURL=noUntypedPublicSignatureRule.spec.js.map